*********************
Eine begleitende Tour
*********************

Dieser Abschnitt ist eine begleitende Tour einiger in Sage vorhandener
Funktionen. Um viele weitere Beispiele zu sehen, schauen Sie sich
`Sage Constructions
<http://passagemath.org/docs/latest/html/en/constructions/index.html>`_ an. Dies ist
dazu gedacht, die allgemeine Frage  "Wie konstruiere ich ... in Sage?"
zu beantworten. Schauen Sie sich auch das `Sage Reference Manual
<http://passagemath.org/docs/latest/html/en/reference/index.html>`_  an, welches
Tausende weiterer Beispiele beinhaltet. Beachten Sie auch, dass Sie
diese Tour interaktiv im Sage-Notebook durcharbeiten können,
indem Sie auf den ``Help`` Link klicken.

(Falls Sie dieses Tutorial im Sage-Notebook sehen, drücken Sie
``shift-enter`` um die Eingabe-Zellen auszuwerten. Sie können die
Eingabe sogar verändern bevor Sie ``shift-enter`` drücken. Auf einigen Macs
müssen Sie vielleicht ``shift-return`` anstelle von ``shift-enter`` drücken.)

.. toctree::

   tour_assignment
   tour_help
   tour_algebra
   tour_plotting
   tour_functions
   tour_rings
   tour_linalg
   tour_polynomial
   tour_groups
   tour_numtheory
   tour_advanced
